.. _api_reference:

API Reference
=============

The following gives detailed information about all pyrato functions sorted
according to their modules.

Modules
-------

.. toctree::
   :maxdepth: 1

   modules/analytic
   modules/dsp
   modules/edc
   modules/parameters
   modules/parametric
